@@ -11,7 +11,7 @@ pub struct Request<'a, T> {
 impl<'a, T> Request<'a, T> {
 	pub fn new(method: &'a str, tag: u8, arguments: T) -> Self {
 		Self{
-			method: method,
+			method,
 			tag,
 			arguments
 		}
